Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(820)

Unified Diff: Source/core/dom/TreeScope.h

Issue 106423003: [oilpan] Rename visit to mark. (Closed) Base URL: svn://svn.chromium.org/blink/branches/oilpan
Patch Set: Address comments. Created 7 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/dom/ShadowRoot.cpp ('k') | Source/core/dom/TreeScope.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/dom/TreeScope.h
diff --git a/Source/core/dom/TreeScope.h b/Source/core/dom/TreeScope.h
index 62b9afdc1aa688f2da9d253590cb6b8662906364..e19afd1eb6212d82d3da8ddeb8794f1f6f22a366 100644
--- a/Source/core/dom/TreeScope.h
+++ b/Source/core/dom/TreeScope.h
@@ -105,9 +105,12 @@ public:
void trace(Visitor*);
- // We can't pass TreeScope pointer into Visitor::visit function directly because it does not coincide with the actual start of the object and
- // visitor has to access object header. Thus we need a helper method that would correctly adjust the pointer before passing it into the visitor.
- virtual void visitWith(Visitor*) const;
+ // We can't pass TreeScope pointer into Visitor::mark function
+ // directly because it does not coincide with the actual start of
+ // the object and visitor has to access object header. Thus we
+ // need a helper method that correctly adjusts the pointer
+ // before passing it into the visitor.
+ virtual void adjustAndMark(Visitor*) const;
protected:
static TreeScope* create()
@@ -161,7 +164,7 @@ TreeScope* commonTreeScope(Node*, Node*);
template<> class TraceTrait<TreeScope> {
public:
- static void visit(Visitor* v, const TreeScope* self) { self->visitWith(v); }
+ static void mark(Visitor* v, const TreeScope* self) { self->adjustAndMark(v); }
static intptr_t getTypeMarker() { return 0; }
static void checkTypeMarker(Visitor* visitor, const TreeScope* t) { }
static void trace(Visitor* visitor, void* self)
« no previous file with comments | « Source/core/dom/ShadowRoot.cpp ('k') | Source/core/dom/TreeScope.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698